@@ -1,5 +1,4 @@
-AUC <-
-function(x, y, Method="Linear")
+AUC = function(x, y, down="Linear")
 {
   n = length(x)
   if (n != length(y) | !is.numeric(x) | !is.numeric(y)) stop("Bad Input!")  
@@ -10,15 +9,15 @@ function(x, y, Method="Linear")
     if (y[i] >= y[i-1]) {
       Res[i,1] = (x[i] - x[i-1])*(y[i] + y[i-1])/2 
       Res[i,2] = (x[i] - x[i-1])*(x[i]*y[i] + x[i-1]*y[i-1])/2
-    } else if (Method=="Linear") {
+    } else if (down == "Linear") {
       Res[i,1] = (x[i] - x[i-1])*(y[i] + y[i-1])/2 
       Res[i,2] = (x[i] - x[i-1])*(x[i]*y[i] + x[i-1]*y[i-1])/2
-    } else if (Method=="Log") {
+    } else if (down == "Log") {
       k = (log(y[i-1]) - log(y[i]))/(x[i] - x[i-1]) # -k slope in y-log scale
       Res[i,1] = (y[i-1] - y[i])/k
       Res[i,2] = (x[i-1]*y[i-1] - x[i]*y[i])/k + (y[i-1] - y[i])/k/k
     } else {
-      stop("Unknown Method!") 
+      stop("Unknown method!") 
     }
   }
   Result = cbind(cumsum(Res[,1]), cumsum(Res[,2]))
